# For Emacs: -*- mode:cperl; eval: (folding-mode 1) -*-

package Task::Lingua::Num2Word;

use 5.16.0;
use utf8;
use warnings;

our $VERSION = '0.2603260';

1;

__END__

=pod

=encoding utf-8

=head1 NAME

Task::Lingua::Num2Word - Install all PetaMem number-to-word conversion modules

=head1 VERSION

version 0.2603260

=head1 DESCRIPTION

Installing this module will pull in the L<Lingua::Num2Word> dispatcher
and all language-specific Lingua::*::Num2Word modules (including variants
named Numbers, Number, Nums2Words, Numeros) maintained by PetaMem.

=head1 AUTHORS

 specification, maintenance:
   Richard C. Jelinek E<lt>rj@petamem.comE<gt>
 coding (until 2005):
   Roman Vasicek E<lt>info@petamem.comE<gt>
 maintenance, coding (2025-present):
   PetaMem AI Coding Agents

=head1 COPYRIGHT

Copyright (c) PetaMem, s.r.o. 2004-present

=head1 LICENSE

This module is free software; you can redistribute it and/or modify it
under the same terms as the Artistic License 2.0 or the BSD 2-Clause
License. See the LICENSE file in the distribution for details.

=cut
